from cyberonix.main.tools import *
#from main.tools import Anonymity
#from main.tools import Framework
import os
def exit_program():
        os.system("clear")
        banner.main()
        print("\033[38;5;105m","[+] Thanks visit again".title())

def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("TOOLS")
        # import information_gathering

        list_attacks=[" Information Gathering"," Vulnerability Analysis"," Web Application Analysis"," Password Attacks"," Wireless Attacks"," Exploitation Tools"," Sniffing and Spoofing"," Post Exploitation"," Anonymity","Framework","Pentesting In Bug-Bounty","Digital Forensics Tools","go back"]
        #for output with index
        for i in range(len(list_attacks)):
                print(colors.options,f"{i+1}) {list_attacks[i]}".title(),colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            print("\n[+] Information Gathering Section")
            os.system("clear")
            information_gathering.main()
        elif option == "2":
            print("\n[+] Vulnerability Analysis")
            os.system("clear")
            Vulnerability_Analysis.main()
        elif option == "3":
            print("\n[+] Web Application Analysis")
            os.system("clear")
            WEB_Application_Analysis.main()
        elif option == "4":
            print("\n[+] Password Attacks")
            os.system("clear")
            Password_Hacking.main()
        elif option == "5":
            print("\n[+] Wireless Attacks")
            os.system("clear")
            Wireless_Hacking.main()
        elif option == "6":
            print("\n[+] Exploitation Tools")
            os.system("clear")
            Exploitation_Tools.main()
        elif option == "7":
            print("\n[+] Sniffing and Spoofing")
            os.system("clear")
            Sniffing_and_Spoofing.main()
        elif option == "8":
            print("\n[+] Post Exploitation")
            os.system("clear")
            PostExploitationAttacks.main()
        elif option == "9":
            print("\n[+] Anonymity")
            os.system("clear")
            Anonymity.main()
        elif option == "10":
            print("\n[+]Framework")
            os.system("clear")
            Framework.main()
        elif option == "11":
            print("\n[+] Pentesting In Bug-Bounty")
            os.system("clear")
            Pentesting_Bug_Bounty.main()
        elif option == "12":
            print("\n[+] Digital Forensics Tools ")
            os.system("clear")
            forensic.main()
        else:
            exit_program()
            return

if __name__ == "__main__": 
    main()



import dns.resolver, requests, socket, os, time
import random
from cyberonix.main import tool
from cyberonix.main.tools import *
from selenium import webdriver
from ipwhois import IPWhois
from cyberonix.main.tools import colors, banner,template,Recommended_Tool
import argparse, itertools

def tools(name):
    try:
        getattr(information_gathering, name)()
        getattr(Vulnerability_Analysis, name)()
        getattr(WEB_Application_Analysis, name)()
        getattr(Password_Hacking, name)()
        getattr(Wireless_Hacking, name)()
        getattr(Exploitation_Tools, name)()
        getattr(Sniffing_and_Spoofing, name)()
        getattr(PostExploitationAttacks, name)()
        getattr(Anonymity, name)()
        getattr(Framework, name)()
        getattr(Pentesting_Bug_Bounty, name)()
        getattr(forensic, name)()
    except KeyboardInterrupt:
        return
    except Exception as err:
        return
    
def getip(url='',path='',output=''):
        banner.main()
        banner.attack("Get Ip")
        url=domain()['no_http'](url)
        if url!="ip":
            if path != "":
                try:
                    f = open(path, "r")
                    urls = f.read()
                    urls = urls.split("\n")
                    for url in urls:
                        if url != "":
                            url=domain()['no_http'](url)
                            if url!='ip':
                                    try:
                                        ip_address = socket.gethostbyname(url)
                                        if output != "":
                                            outputfunc(output, f"{url}\t --> \t{ip_address}")

                                        print(
                                            f"{colors.green}[+]{url}\t --> \t{ip_address}{colors.reset}"
                                        )
                                    except Exception as err:
                                        if output != "":
                                            outputfunc(output, f"{url}\t --> Something Went Wrong --> [!] {err}")
                                        print(f"{colors.red}[-]{url}\t --> Something Went Wrong --> [!] {err}{colors.reset}")
                            else:
                                print(f"{colors.red}[-]{url}\t -->\tYou Have Entered IP{colors.reset}")
                                if output != "":
                                            outputfunc(output, f"{url}\t -->\tYou Have Entered IP")

                except KeyboardInterrupt:
                    exit_program()
                except Exception as err:
                    print(
                        f"{colors.red}[-] Something Went Wrong\n[!] {err}\n[!] Check Your File location"
                    )
            else:
                url=domain()['no_http'](url)
                if url!='ip':
                        try:
                            ip_address = socket.gethostbyname(url)
                            if output != "":
                                outputfunc(output, f"{url}\t --> \t{ip_address}")

                            print(
                                f"{colors.green}[+]{url}\t --> \t{ip_address}{colors.reset}"
                            )
                        except Exception as err:
                            if output != "":
                                outputfunc(output, f"{url}\t --> Something Went Wrong --> [!] {err}")
                            print(f"{colors.red}[-]{url}\t --> Something Went Wrong --> [!] {err}{colors.reset}")
                else:
                    print(f"{colors.red}[-]{url}\t -->\tYou Have Entered IP{colors.reset}")
                    if output != "":
                                outputfunc(output, f"{url}\t -->\tYou Have Entered IP")
        else:
            print(f"{colors.red}[-] Something Went Wrong\n[!] Maybe You have Entered Ip")


def dnsrecords(url="", names='',path='',output=''):
        banner.main()
        banner.attack("DNS Records")
        names = names.upper()
        names = names.split(",")
        url=domain()['no_http'](url)
        if url!="ip":
            if path != "":
                try:
                    f = open(path, "r")
                    urls = f.read()
                    urls = urls.split("\n")
                    for url in urls:
                        if url != "":
                            url=domain()['no_http'](url)
                            if url!='ip':
                                for name in names:
                                    try:
                                        answers = dns.resolver.resolve(url, name)
                                        for answer in answers:
                                            if output != "":
                                                outputfunc(output, f"{url}\t -->\t{name}\t -->\t{answer}")
                                            print(
                                                f"{colors.blue}[+]{url}\t -->\t{name}\t -->\t{colors.green}{answer}{colors.reset}"
                                            )
                                    except dns.rdatatype.UnknownRdatatype:
                                        if output != "":
                                            outputfunc(output, f"{url}\t -->\t{name}\t -->\tWrong Record Input")
                                        print(f"{colors.red}[-]{url}\t -->\t{name}\t -->\tWrong Record Input{colors.reset}")
                                    except dns.resolver.NoAnswer:
                                        if output != "":
                                            outputfunc(output, f"{url}\t -->\t{name}\t -->\tRecord Found")
                                        print(f"{colors.red}[-]{url}\t -->\t{name}\t -->\tNo {name} Record Found{colors.reset}")
                                    except dns.resolver.NXDOMAIN:
                                        print(f"{colors.red}[-]{url}\t -->\t{name}\t -->\tHost {domain} Not Found{colors.reset}")
                                        if output != "":
                                            outputfunc(output, f"{url}\t -->\t{name}\t -->\tHost {domain} Not Found")
                                    except Exception as err:
                                        print(f"{colors.red}[-]{url}\t -->\t{name}\t -->\terr:{err}{colors.reset}")
                                        if output != "":
                                            outputfunc(output, f"{url}\t -->\t{name}\t -->\terr:{err}")

                            else:
                                print(f"{colors.red}[-]{url}\t -->\tYou Have Entered IP{colors.reset}")
                                if output != "":
                                            outputfunc(output, f"{url}\t -->\tYou Have Entered IP")

                except KeyboardInterrupt:
                    exit_program()
                except Exception as err:
                    print(
                        f"{colors.red}[-] Something Went Wrong\n[!] {err}\n[!] Check Your File location"
                    )
            else:
                for name in names:
                    try:
                        answers = dns.resolver.resolve(url, name)
                        for answer in answers:
                            if output != "":
                                outputfunc(output, f"{url}\t -->\t{name}\t -->\t{answer}")
                            print(
                                f"{colors.blue}[+]{url}\t -->\t{name}\t -->\t{colors.green}{answer}{colors.reset}"
                            )
                    except dns.rdatatype.UnknownRdatatype:
                        if output != "":
                            outputfunc(output, f"{url}\t -->\t{name}\t -->\tWrong Record Input")
                        print(f"{colors.red}[-]{url}\t -->\t{name}\t -->\tWrong Record Input{colors.reset}")
                    except dns.resolver.NoAnswer:
                        if output != "":
                            outputfunc(output, f"{url}\t -->\t{name}\t -->\tRecord Found")
                        print(f"{colors.red}[-]{url}\t -->\t{name}\t -->\tNo {name} Record Found{colors.reset}")
                    except dns.resolver.NXDOMAIN:
                        print(f"{colors.red}[-]{url}\t -->\t{name}\t -->\tHost {domain} Not Found{colors.reset}")
                        if output != "":
                            outputfunc(output, f"{url}\t -->\t{name}\t -->\tHost {domain} Not Found")
                    except Exception as err:
                        print(f"{colors.red}[-]{url}\t -->\t{name}\t -->\terr:{err}{colors.reset}")
                        if output != "":
                            outputfunc(output, f"{url}\t -->\t{name}\t -->\terr:{err}")

        else:
            print(f"{colors.red}[-] Something Went Wrong\n[!] Maybe You have Entered Ip")



def checking(result_str):

        print(f"{colors.green}Checking for password{colors.reset}")
        passwords = [
            "https://raw.githubusercontent.com/danielmiessler/SecLists/master/Passwords/xato-net-10-million-passwords.txt",
            "https://raw.githubusercontent.com/danielmiessler/SecLists/master/Passwords/Common-Credentials/10-million-password-list-top-1000000.txt",
            "https://raw.githubusercontent.com/danielmiessler/SecLists/master/Passwords/Common-Credentials/10-million-password-list-top-100000.txt",
            "https://raw.githubusercontent.com/danielmiessler/SecLists/master/Passwords/xato-net-10-million-passwords-1000000.txt",
        ]
        for link in range(len(passwords)):
            pass_check(passwords[link], result_str, link)


def pass_check(url, password, number):
        print(f"{colors.blue}Test {number}{colors.reset}")
        raw = requests.get(url)
        lists = raw.text.split("\n")
        for i in lists:
            if password == i:
                print(f"{colors.red}FAILED{colors.reset}")
        else:
            print(f"{colors.green}PASSED{colors.reset}")


def exit_program():
    print("\033[38;5;105m", "[+] Thanks visit again".title())
    exit()


def asnrecord(path="", url="", output=""):
        banner.main()
        banner.attack("ASN")
        if path != "":
            try:
                f = open(path, "r")
                urls = f.read()
                urls = urls.split("\n")
                for url in urls:
                    if url != "":
                        valid=ip_valid(url)
                        if valid==1:
                            try:
                                ipwhois = IPWhois(url)
                                result = ipwhois.lookup_rdap()
                                if output != "":
                                    outputfunc(output, f"{url}\t --> {result['asn']}")
                                print(
                                    f"{colors.blue}[+] {url}\t --> {colors.green}{result['asn']}{colors.reset}"
                                )
                            except KeyboardInterrupt:
                                exit_program()
                            except Exception as err:
                                if output != "":
                                    outputfunc(output, f"{url}\t --> err:{err}")
                                    print(
                                        f"{colors.red}[+] {url}\t --> {colors.red}err:{err}{colors.reset}"
                                    )
                        else:
                            print(f"{colors.red}[-] Something Went Wrong\n[!] Maybe You have Entered Domain Or Ip Range Is Wrong")
            except KeyboardInterrupt:
                exit_program()
            except Exception as err:
                print(
                    f"{colors.red}[-] Something Went Wrong\n[!] {err}\n[!] Check Your File location"
                )
        else:
            try:
                valid=ip_valid(url)
                if valid==1:
                    ipwhois = IPWhois(url)
                    result = ipwhois.lookup_rdap()
                    if output != "":
                        outputfunc(output, f"{url}\t --> {result['asn']}")
                    print(
                        f"{colors.blue}[+] {url}\t --> {colors.green}{result['asn']}{colors.reset}"
                    )
                else:
                    print(f"{colors.red}[-] Something Went Wrong\n[!] Maybe You have Entered Domain Or Ip Range Is Wrong")
            except KeyboardInterrupt:
                exit_program()
            except:
                if output != "":
                    outputfunc(output, f"{url}\t --> Something Went Wrong")
                print(
                    f"{colors.red}[+] {url}\t --> {colors.red}Something Went Wrong{colors.reset}"
                )


def outputfunc(addr, line):

    f = open(addr, "a")
    f.write(line)
    f.write("\n")
    f.close()


def http_status_code(path="", url="", output=""):
        link=domain()['check_http'](url)
        banner.main()
        banner.attack("HTTP Status Code")
        if link=="ip":
            print(f'{colors.red}Something Went Wrong\n[!] You Have Entered IP{colors.reset}')
            return
        else:
            if path != "":
                try:
                    f = open(path, "r")
                    urls = f.read()
                    urls = urls.split("\n")
                    for url in urls:
                        if url != "":
                            link=domain()['check_http'](url)
                            if link=="ip":
                                print(
                                            f"{colors.red}[+] {url}\t --> {colors.red}You Have Entered Ip{colors.reset}"
                                        )
                            else:
                                for url in link:
                                    try:
                                        headers = {
                                            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.36"
                                        }
                                        response = requests.get(url,allow_redirects=False, headers=headers, timeout=20)
                                        status = str(response.status_code)
                                        if status[0] == "1":
                                            print(
                                                f"{colors.blue}[+] {url}\t --> {colors.light_blue}{status}{colors.reset}"
                                            )
                                        elif status[0] == "2":
                                            print(
                                                f"{colors.blue}[+] {url}\t --> {colors.green}{status}{colors.reset}"
                                            )
                                        elif status[0] == "3":
                                            print(
                                                f"{colors.blue}[+] {url}\t --> {colors.yellow}{status}{colors.reset}",end=''
                                            )
                                            try:
                                                response = requests.get(url, headers=headers, timeout=20)
                                                status = str(response.status_code)
                                                new_url=str(response.url)
                                                if status[0] == "1":
                                                    print(
                                                        f"{colors.blue} --> {colors.light_blue}{status} -->{colors.blue} {new_url}{colors.reset}"
                                                    )
                                                elif status[0] == "2":
                                                    print(
                                                        f"{colors.blue} --> {colors.green}{status} -->{colors.blue} {new_url}{colors.reset}"
                                                    )
                                                elif status[0] == "3":
                                                    print(
                                                        f"{colors.blue} --> {colors.yellow}{status} -->{colors.blue} {new_url}{colors.reset}"
                                                    )
                                                elif status[0] == "4":
                                                    print(
                                                        f"{colors.blue} --> {colors.red}{status} -->{colors.blue} {new_url}{colors.reset}"
                                                    )
                                                elif status[0] == "5":
                                                    print(
                                                        f"{colors.blue} --> {colors.purple}{status} -->{colors.blue} {new_url}{colors.reset}"
                                                    )
                                                else:
                                                    print(
                                                        f"{colors.blue} --> {colors.green}{status} -->{colors.blue} {new_url}{colors.reset}"
                                                    )
                                            except Exception as err:
                                                if "timed out" in str(err):
                                                    err = "Connection Time Out"
                                                print(
                                                    f"{colors.red} --> {colors.red}{err}{colors.reset}"
                                                )


                                        elif status[0] == "4":
                                            print(
                                                f"{colors.blue}[+] {url}\t --> {colors.red}{status}{colors.reset}"
                                            )
                                        elif status[0] == "5":
                                            print(
                                                f"{colors.blue}[+] {url}\t --> {colors.purple}{status}{colors.reset}"
                                            )
                                        else:
                                            print(
                                                f"{colors.blue}[+] {url}\t --> {colors.green}{status}{colors.reset}"
                                            )
                                        if output != "":
                                            outputfunc(output, f"{url}\t --> {status}")
                                    except Exception as err:
                                        if "timed out" in str(err):
                                            err = "Connection Time Out"
                                        if output != "":
                                            outputfunc(output, f"{url}\t --> {err}")
                                        print(
                                            f"{colors.red}[-] {url}\t --> {colors.red}{err}{colors.reset}"
                                        )
                                    time.sleep(0.5)
                except KeyboardInterrupt:
                    exit_program()

                except Exception as err:
                    print(f"{colors.red}[-] Something Went Wrong\n[!] {err}")
            else:
                try:
                    if url != "":
                        for url in link:
                            try:
                                headers = {
                                    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.36"
                                }
                                response = requests.get(url,allow_redirects=False , headers=headers, timeout=20)
                                status = str(response.status_code)
                                if status[0] == "1":
                                    print(
                                        f"{colors.blue}[+] {url}\t --> {colors.light_blue}{status}{colors.reset}"
                                    )
                                elif status[0] == "2":
                                    print(
                                        f"{colors.blue}[+] {url}\t --> {colors.green}{status}{colors.reset}"
                                    )
                                elif status[0] == "3":
                                    print(
                                        f"{colors.blue}[+] {url}\t --> {colors.yellow}{status}{colors.reset}"
                                    )
                                elif status[0] == "4":
                                    print(
                                        f"{colors.blue}[+] {url}\t --> {colors.red}{status}{colors.reset}"
                                    )
                                elif status[0] == "5":
                                    print(
                                        f"{colors.blue}[+] {url}\t --> {colors.purple}{status}{colors.reset}"
                                    )
                                else:
                                    print(
                                        f"{colors.blue}[+] {url}\t --> {colors.green}{status}{colors.reset}"
                                    )
                                if output != "":
                                    outputfunc(output, f"{url}\t --> {status}")
                            except Exception as err:
                                if "timed out" in str(err):
                                    err = "Connection Time Out"
                                if output != "":
                                    outputfunc(output, f"{url}\t --> {err}")
                                print(
                                    f"{colors.red}[+] {url}\t --> {colors.red}{err}{colors.reset}"
                                )
                            time.sleep(0.5)
                except KeyboardInterrupt:
                    exit_program()

                except Exception as err:
                    print(f"{colors.red}[-] Something Went Wrong\n[!] {err}")


def password_gen(
    upper=True, lower=True, digit=True, punctuation=True, length="8", check=True
):
        banner.main()
        banner.attack("Password Generators")
        ascii_lowercase = "abcdefghijklmnopqrstuvwxyz"
        ascii_uppercase = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        string_digits = "0123456789"
        string_punctuation = r"""!"#$%&'()*+,-./:;<=>?@[\]^_`{|}~"""
        main_password = ""
        if upper:
            main_password += ascii_uppercase
        if lower:
            main_password += ascii_lowercase
        if digit:
            main_password += string_digits
        if punctuation:
            main_password += string_punctuation
        try:
            result_str = "".join(random.choice(main_password) for i in range(int(length)))
            print(
                f"{colors.blue}[+] Your Passwrod Is: {colors.green}{result_str}{colors.reset}"
            )
            if check:
                checking(result_str)
        except KeyboardInterrupt:
                exit_program()
        except IndexError:
            print(
                f"{colors.red}[-] Please Specify atleast one argument (--upper,--lower,--digits,--punctuation) {colors.reset}"
            )
def generate_wordlist(characters=True, min_length=True, max_length=True, output_file=True):
    try:
        with open(output_file, 'w') as file:

            for length in range(min_length, max_length + 1):

                for combination in itertools.product(characters, repeat=length):

                    word = ''.join(combination)
                    file.write(word + '\n')
        print(f"[+] Wordlist generated and saved to {output_file}.txt")
    except KeyboardInterrupt:
                exit_program()
def remove_dublicates(location,output=''):
        f=open(location,'r')
        lines=f.read()
        lines=lines.split('\n')
        readed=[]
        for line in lines:
            if line not in readed:
                readed.append(line)
        f.close()
        if output=='':
            if not os.path.isdir("duplicate"):
                os.system("mkdir duplicate")
            location=location.split('.')
            location=location[0].split('/')
            fn=open(f"duplicate/{location[(len(location)-1)]}_removed.txt",'a')
            for read in readed:
                fn.write(read)
                fn.write('\n')
            fn.close()
        else:
            location=location.split('.')
            location=location[0].split('/')
            fn=open(f'{output}',"a")
            for read in readed:
                fn.write(read)
                fn.write('\n')
            fn.close()


        

def screenshot(path="", url="",output=''):
        link=domain()['check_http'](url)
        banner.main()
        banner.attack("Screenshotting")
        if link=="ip":
            print(f'{colors.red}Something Went Wrong\n[!] You Have Entered IP{colors.reset}')
            return
        else:
            if path != "":
                try:
                    f = open(path, "r")
                    urls = f.read()
                    urls = urls.split("\n")
                    for url in urls:
                        if url != "":
                            link=domain()['check_http'](url)
                            if link=="ip":
                                print(
                                        f"{colors.red}[-] {url}\t --> {colors.red}It Is a IP{colors.reset}"
                                    )
                            else:
                                for url in link:
                                    driver_path = "main/tools/.driver/geckodriver"
                                    firefox_options = webdriver.FirefoxOptions()
                                    firefox_options.headless = True
                                    driver = webdriver.Firefox(
                                        executable_path=driver_path, options=firefox_options
                                    )
                                    try:
                                        driver.get(url)
                                        url_new = url.split("//")
                                        path = os.getcwd()
                                        if output!='':
                                            screenshot_filename=f'{output}/{url_new[0]}_{url_new[1].replace("/","_")}.png'
                                        else:
                                            if not os.path.isdir("Screenshot"):
                                                os.system("mkdir Screenshot")
                                            screenshot_filename = f'{path}/Screenshot/{url_new[0]}_{url_new[1].replace("/","_")}.png'
                                        driver.save_screenshot(screenshot_filename)
                                        print(
                                            f"{colors.blue}[+] {url}\t --> {colors.green}Screenshot saved to {screenshot_filename}{colors.reset}"
                                        )
                                        driver.quit()
                                    except KeyboardInterrupt:
                                        exit_program()
                                    except Exception as err:
                                        print(
                                            f"{colors.red}[+] {url}\t --> {colors.red}Something Went Wrong\n[!] {err}{colors.reset}"
                                        )
                                    time.sleep(0.5)
                except Exception as err:
                    print(
                        f"{colors.red}[-] Something Went Wrong\n[!] {err}\n[!] Check Your File location"
                    )
            else:
                driver_path = "./main/tools/.driver/geckodriver"
                firefox_options = webdriver.FirefoxOptions()
                firefox_options.headless = True
                driver = webdriver.Firefox(executable_path=driver_path, options=firefox_options)
                for url in link:
                    try:
                        driver.get(url)
                        url_new = url.split("//")
                        path = os.getcwd()
                        if output!='':
                            if not os.path.isdir(output):
                                os.mkdir(output)
                            screenshot_filename=f'{output}/{url_new[0]}_{url_new[1].replace("/","_")}.png'
                        else:
                            if not os.path.isdir("Screenshot"):
                                os.system("mkdir Screenshot")
                            screenshot_filename = f'{path}/Screenshot/{url_new[0]}_{url_new[1].replace("/","_")}.png'
                        if not os.path.isdir("Screenshot"):
                            os.system("mkdir Screenshot")
                        driver.save_screenshot(screenshot_filename)
                        print(
                            f"{colors.blue}[+] {url}\t --> {colors.green}Screenshot saved to {screenshot_filename}{colors.reset}"
                        )
                        #driver.quit()
                        #time.sleep(5)
                    except KeyboardInterrupt:
                        exit_program()
                    except Exception as err:
                        print(
                            f"{colors.red}[+] {url}\t --> {colors.red}Something Went Wrong\n[!] {err}{colors.reset}"
                        )
                    time.sleep(0.5)
                driver.quit()
def domain():
    def check_http(url):
        urls=[]
        if "https://" not in url and "http://" not in url:
            valid=ip_valid(url)
            if valid==3:
                urls.append("http://"+url)
                urls.append("https://"+url)
            else:
                urls="ip"
        else:
            urls.append(url)
        return urls
    def no_http(url):
        if "http://" and "https://" not in url:
            valid=ip_valid(url)
            if valid==3:
                return url
            else:
                url="ip"
        else:
            if "http://" in url:
                url=url.split("http://")
                url=url[1]
            elif "https://" in url:
                url=url.split("https://")
                url=url[1]

            return url
    return {"check_http":check_http,"no_http":no_http}

def ip_valid(user_input):
    parts = user_input.split(".")
    for part in parts:
        try:
            part=int(part)
            if len(parts) == 4:
                is_ip_address = True
                for part in parts:
                    if not part.isdigit() or not (0 <= int(part) <= 255):
                        is_ip_address = False
                        break
                if is_ip_address:
                    return 1
                else:
                    return 2
        except:
            return 3



from cyberonix.main.tools import banner, colors, template
import os

import requests
from bs4 import BeautifulSoup


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Secure Transmission")
        list_vulns = [
            "Check SSL Version, Algorithms, Key length",
            "Check for Digital Certificate Validity",
            "Check credentials only delivered over HTTPS",
            "Check session tokens only delivered over HTTPS",
            "Check if HTTP Strict Transport Security (HSTS) in use",
            "Go back",
        ]
        for i in range(len(list_vulns)):
            print(colors.options, f"{i+1}) {list_vulns[i]}".title(), colors.reset)
        try:
            vulns = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if vulns == "1":
            os.system("clear")
            # github=github_getting_text("","")
            template.template(
                "Check SSL Version, Algorithms",
                "no-tools",
                "",
                {
                    "10 Online Tools to Test SSL, TLS and Latest Vulnerability": "https://geekflare.com/ssl-test-certificate/",
                    "Testing for Weak SSL TLS Ciphers": "https://owasp.org/www-project-web-security-testing-guide/v41/4-Web_Application_Security_Testing/09-Testing_for_Weak_Cryptography/01-Testing_for_Weak_SSL_TLS_Ciphers_Insufficient_Transport_Layer_Protection",
                    "How to Verify the SSL Key Length": "https://www.rapidsslonline.com/ssl/how-to-verify-the-ssl-key-length",
                },
            )
            # writeup.writeup({"10 Online Tools to Test SSL, TLS and Latest Vulnerability":"https://geekflare.com/ssl-test-certificate/","Testing for Weak SSL TLS Ciphers":"https://owasp.org/www-project-web-security-testing-guide/v41/4-Web_Application_Security_Testing/09-Testing_for_Weak_Cryptography/01-Testing_for_Weak_SSL_TLS_Ciphers_Insufficient_Transport_Layer_Protection","How to Verify the SSL Key Length":"https://www.rapidsslonline.com/ssl/how-to-verify-the-ssl-key-length/"},"Check SSL Version, Algorithms, Key length")
        elif vulns == "2":
            os.system("clear")
            # github
            template.template(
                "Check for Digital Certificate Validity",
                "no-tools",
                "",
                {
                    "A closer look at Digital Certificates": "https://medium.com/@mehulgala77/a-closer-look-at-digital-certificates-9ce5a4c56f75"
                },
            )
        elif vulns == "3":
            os.system("clear")
            template.template(
                "Check credentials only delivered over HTTPS",
                "no-tools",
                "",
                {
                    "Testing for Credentials Transported over an Encrypted Channel": "https://owasp.org/www-project-web-security-testing-guide/v41/4-Web_Application_Security_Testing/04-Authentication_Testing/01-Testing_for_Credentials_Transported_over_an_Encrypted_Channel",
                    "Penetration testing of Credential Data over Encrypted Channel": "https://www.hackingloops.com/penetration-testing-of-credential-data-over-encrypted-channel/",
                },
            )
        elif vulns == "4":
            os.system("clear")
            template.template(
                "Check session tokens only delivered over HTTPS",
                "no-tools",
                "",
                {
                    "Testing for Exposed Session Variables": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/06-Session_Management_Testing/04-Testing_for_Exposed_Session_Variables",
                    "Using Burp to Test Session Token Handling": "https://portswigger.net/support/using-burp-to-test-session-token-handling",
                },
            )

        elif vulns == "5":
            os.system("clear")
            template.template(
                "Check if HTTP Strict Transport Security (HSTS) in use",
                "no-tools",
                "",
                {
                    "HSTS (HTTP Strict Transport Security) Test": "https://geekflare.com/tools/hsts-test",
                    "What Is HSTS and Why Should I Use It?": "https://www.acunetix.com/blog/articles/what-is-hsts-why-use-it/",
                },
            )
        else:
            return


def vuln_options():
    print(f"{colors.options}1) Tools")
    print(f"2) Write-ups")
    print(f"3) Go Back..")
    try:
        ask = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
    except KeyboardInterrupt:
        return
    return ask


def github_getting_text(link, selector, indexvalue):
    print(f"Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return "{colors.red}NotLloaded Because No Internet Connection{colors.reset}"


if __name__ == "__main__":
    main()



#!/usr/bin/python3
import os
import requests
from cyberonix.main.tools import banner, colors, template, information_gathering, WEB_Application_Analysis
from bs4 import BeautifulSoup


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Vulnerability Analysis")
        list_attacks = ["Wpscan\t\t(Recommended)", "Wireshark\t\t(Recommended)",
                        "Wapiti", "Nmap\t\t(Recommended)", "Legion", "Nikto", "Wfuzz", "go back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(
                f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            print("\n[+] Wpscan")
            wpscan()
        elif option == "2":
            print("\n[+] Wireshark")
            wireshark()
        elif option == "3":
            print("\n[+] Wapiti")
            WEB_Application_Analysis.wapiti()
        elif option == "4":
            print("\n[+] Nmap")
            information_gathering.nmap()
        elif option == "5":
            print("\n[+] legion")
            legion()
        elif option == "6":
            print("\n[+] Nikto")
            nikto()
        elif option == "7":
            print("\n[+] Wfuzz")
            wfuzz()
        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, 'html.parser')
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}NotLloaded Because No Internet Connection{colors.reset}"


def tool_writeups():
    print(f"{colors.options}1) TOOL(About,Installation)")
    print(f"2) Write Ups")
    print(f"3) Go Back..")
    try:
        ask = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
    except KeyboardInterrupt:
        return
    return ask

def wfuzz():
    os.system("clear")
    github = "Wfuzz is a web application brute force tool used to identify web application vulnerabilities by scanning web content, such as directories and files, for hidden or non-linked content. Wfuzz can be used to test input validation, error handling, and access control mechanisms. It is a command-line tool and allows users to customize requests to send payloads, which makes it very flexible and powerful for web application penetration testing. Wfuzz is written in Python and can be used on Linux, Windows, and macOS. It is open-source and free to use."
    template.template(
                "wfuzz", "wfuzz --help", github.strip(), {"How to use Wfuzz to find web application vulnerabilities":
                                                          "https://www.techtarget.com/searchsecurity/feature/How-to-use-Wfuzz-to-find-web-application-vulnerabilities", }
            )


def wireshark():
    os.system("clear")
    github = "Wireshark is a network traffic analyzer, or sniffer, for Linux, macOS, BSD and other Unix and Unixlike operating systems and for Windows. It uses Qt, a graphical user interface library, and libpcap and npcap as packet capture and filtering libraries."
    template.template("wireshark", "wireshark", github.strip(), {'How To Install & Use Wireshark On Kali Linux': 'https://infosecscout.com/wireshark-on-kali-linux/', 'Wireshark Tool Documentation': 'https://www.kali.org/tools/wireshark/', 'Wireshark Training': 'https://www.wireshark.org/docs/', 'Wireshark – Resources': 'https://blog.inf.ed.ac.uk/atate/2023/01/14/wireshark-resources/',
                              'Kerberos Wireshark Captures: A Windows Login Example': 'https://medium.com/@robert.broeckelmann/kerberos-wireshark-captures-a-windows-login-example-151fabf3375a', 'Wireshark – Packet Capturing and Analyzing': 'https://www.geeksforgeeks.org/wireshark-packet-capturing-and-analyzing/', 'Wireshark Tutorial: Decrypting HTTPS Traffic': 'https://unit42.paloaltonetworks.com/wireshark-tutorial-decrypting-https-traffic/'})
def legion():
    os.system("clear")
    github = github_getting_text(
        "https://github.com/GoVanguard/legion", 'p[class="f4 my-3"]', 0)
    template.template("legion", "legion", github.strip(), {"Legion: The best all in one network mapping tool": "https://techyrick.com/legion-kali-linux/", "An Overview Of Network Penetration Testing Using Legion Framework": "https://www.c-sharpcorner.com/article/an-overview-of-network-penetration-testing-using-legion-framework/#:~:text=What%20is%20Legion%3F,the%20attacks%20against%20targeted%20devices.",
                      'Legion Tool in Kali Linux': 'https://www.geeksforgeeks.org/legion-tool-in-kali-linux', 'Legion -- Test Web Application Vulnerability Automatically': 'https://www.kalilinux.in/2020/09/legion-kali-linux.html', 'How to use Legion application in Kali Linux Video Tutorial': 'https://www.youtube.com/watch?v=0v2_UFhq6zQ'})


def nikto():
    os.system("clear")
    github = github_getting_text(
        "https://en.wikipedia.org/wiki/Nikto_(vulnerability_scanner)", 'p', 1)
    template.template("nikto", "nikto -h", github.strip(), {'What is Nikto and it’s usages ?': 'https://www.geeksforgeeks.org/what-is-nikto-and-its-usages/',
                      'Nikto: A Practical Website Vulnerability Scanner': 'https://securitytrails.com/blog/nikto-website-vulnerability-scanner', 'Nikto Official Docs': 'https://github.com/sullo/nikto/wiki'})


def wpscan():
    os.system("clear")
    github = "WPScan is a security scanner designed for testing the security of websites built using WordPress. WPScan was developed using the Ruby programming language and then released in the first version in 2019. The WPScan security scanner is primarily intended to be used by WordPress administrators and security teams to assess the security status of their WordPress installations. It is used to scan WordPress websites for known vulnerabilities both in WordPress and commonly used WordPress plugins and themes. The code base for WPScan is licensed under GPLv3"
    template.template("wpscan", "wpscan -h", github.strip(), {'WPScan Intro: How to Scan for WordPress Vulnerabilities': 'https://blog.sucuri.net/2021/05/wpscan-how-to-scan-for-wordpress-vulnerabilities.html/', 'WPScan:WordPress Pentesting Framework': 'https://www.hackingarticles.in/wpscanwordpress-pentesting-framework/', 'How To Use WPScan to Test for Vulnerable Plugins and Themes in Wordpress':
                      "https://www.digitalocean.com/community/tutorials/how-to-use-wpscan-to-test-for-vulnerable-plugins-and-themes-in-wordpress", "How to Use wpscan tool in Kali Linux": "https://www.geeksforgeeks.org/how-to-use-wpscan-tool-in-kali-linux/", "WPScan Usage Example [Enumeration + Exploit]": "https://www.cyberpunk.rs/wpscan-usage-example"})


if __name__ == '__main__':
    main()



from cyberonix.main.tools import run_on_browser,colors,banner,template
import os
import threading
def writeup(writeup_dist,name):
    while True:
        os.system("clear")
        banner.main()
        banner.attack(name.title())
        #convert dict keys in list(type casting)
        key=list(writeup_dist.keys())
        key.append("Go Back")
        for i in range(len(key)):
            
            print(colors.options,f"{i+1}) {key[i]}".title(),colors.reset)
        try:
            option =input(f"\n {colors.select}Select An Option -> {colors.reset} ")
            #option-=1
        except KeyboardInterrupt:
            return
        #1-9=int kdsjfhgkjds=int X to type cast safely 
        try:
            threading.Thread(target=run_on_browser.main, args=(writeup_dist[key[(int(option))-1]],)).start()
            #a={"a":1,"b":2}
            # print(2)
        except:
            return



from cyberonix.main.tools import banner, template, colors, writeup
import os
import requests
from bs4 import BeautifulSoup



def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack(f"File Upload")
        list_attacks = ["Tools", "Writeups", "Go Back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            while True:
                os.system("clear")
                banner.main()
                banner.attack(f"Tools")
                list_tools = ["fuxploider","go back"]
                for i in range(len(list_tools)):
                    print(
                        colors.options, f"{i+1}) {list_tools[i]}".title(), colors.reset
                    )
                try:
                    option = input(f"\n {colors.select}Select an Option ->{colors.reset} ")
                except KeyboardInterrupt:
                    return
                if option == "1":
                    print("\n[+] Fuxploider")
                    fuxploider()
                else:
                    break
        elif option == "2":
            # writeup.writeup({"Test Upload of Unexpected File Types":"https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/10-Business_Logic_Testing/08-Test_Upload_of_Unexpected_File_Types","What is Unrestricted File Upload?":"https://www.aptive.co.uk/blog/unrestricted-file-upload-testing/","File Upload General Methodology":"https://book.hacktricks.xyz/pentesting-web/file-upload","File upload vulnerabilities":"https://portswigger.net/web-security/file-upload","File Upload Attacks (Part 2)":"https://blog.yeswehack.com/yeswerhackers/file-upload-attacks-part-2/","Hunting for Bugs in File Upload Feature:":"https://sm4rty.medium.com/hunting-for-bugs-in-file-upload-feature-c3b364fb01ba","How I abused the file upload function to get a high severity vulnerability in Bug Bounty":"https://infosecwriteups.com/how-i-abused-the-file-upload-function-to-get-a-high-severity-vulnerability-in-bug-bounty-7cdcf349080b","Directory Traversal via PHP Multi-File Uploads":"https://nealpoole.com/blog/tag/file-upload/"},"Writups")
            writeup.writeup(
                {
                    "Upload Scanner Website":"https://github.com/portswigger/upload-scanner",
                    "Test Upload of Unexpected File Types": "https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/10-Business_Logic_Testing/08-Test_Upload_of_Unexpected_File_Types",
                    "What is Unrestricted File Upload?": "https://www.aptive.co.uk/blog/unrestricted-file-upload-testing/",
                    "File Upload General Methodology": "https://book.hacktricks.xyz/pentesting-web/file-upload",
                    "File upload vulnerabilities": "https://portswigger.net/web-security/file-upload",
                    "File Upload Attacks (Part 2)": "https://blog.yeswehack.com/yeswerhackers/file-upload-attacks-part-2/",
                    "Hunting for Bugs in File Upload Feature:": "https://sm4rty.medium.com/hunting-for-bugs-in-file-upload-feature-c3b364fb01ba",
                    "How I abused the file upload function to get a high severity vulnerability in Bug Bounty": "https://infosecwriteups.com/how-i-abused-the-file-upload-function-to-get-a-high-severity-vulnerability-in-bug-bounty-7cdcf349080b",
                    "Directory Traversal via PHP Multi-File Uploads": "https://nealpoole.com/blog/tag/file-upload/",
                },
                "File Upload writups",
            )

        else:
            return


def github_getting_text(link, selector, indexvalue):
    print(f"Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}NotLloaded Because No Internet Connection{colors.reset}"

def fuxploider():
    os.system("clear")
    github = "Fuxploider is an open source penetration testing tool that automates the process of detecting and exploiting file upload forms flaws. This tool is able to detect the file types allowed to be uploaded and is able to detect which technique will work best to upload web shells or any malicious file on the desired web server."
    template.template(
                        "fuxploider",
                        "python3 fuxploider.py -h",
                        github,
                        "no-writeups",
                        link="https://github.com/almandin/fuxploider.git",
                        method="github",
                        github_install="git clone https://github.com/almandin/fuxploider.git && python3 -m pip install -r fuxploider/requirements.txt ",
                        github_check="fuxploider"
                    )
                
if __name__ == "__main__":
    main()




from cyberonix.main.tools import banner, colors, template, banner,Recommended_Tool
import os
import requests
from bs4 import BeautifulSoup
import subprocess

def check_tor_installed():
    try:
        # Run the 'which tor' command
        result = subprocess.run(['which', 'tor'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        
        # Decode the output from bytes to string
        output = result.stdout.decode().strip()
        
        if output:
            return
        else:
            os.system("apt install tor -y")     # for tor installation
    except Exception as e:
        print("An error occurred:", str(e))





def main():
    
    while True:
        
        os.system("clear")
        banner.main()
        banner.attack("Anonymity")
        list_attacks = ["Tor", "Anonsurf", "Proxychain", "Nipe ", "go back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            os.system("clear")
            banner.main()
            banner.attack("Tor")
            check_tor_installed()  # Check if Tor is installed
            Recommended_Tool.recommended("tor")

        elif option == "2":
            print("\n[+] Anonsurf")
            anonsurf()
        elif option == "3":
            print("\n[+] ProxyChains ")
            proxychains()        
        elif option == "4":
            print("\n[+] nipe")
            nipe()        
        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, "html.parser")
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"

def anonsurf():
    github = "This repo contains the sources of both the anonsurf and pandora packages from ParrotSec combined into one.Modifications have been made to use the DNS servers of Private Internet Access (instead of FrozenDNS), and fixes for users who don't use the resolvconf application. I have removed some functionality such as the gui and iceweasel in ram.This repo can be compiled into a deb package to correctly install it on a Kali system."
    template.template(
                "kali-anonsurf",
                "anonsurf -h ",
                github.strip(),
                {"How To Setup And Use Anonsurf On kali Linux": "https://www.geeksforgeeks.org/how-to-setup-and-use-anonsurf-on-kali-linux/", "Anonsurf Detail": "https://linuxhint.com/anonsurf/", "How to install and use anonsurf on Kali Linux": "https://www.linuxfordevices.com/tutorials/kali-linux/install-anonsurf",
                 }, method="github", github_install="git clone https://github.com/Und3rf10w/kali-anonsurf.git && cd kali-anonsurf && bash installer.sh", github_check="kali-anonsurf")
        


def proxychains():
    os.system("clear")
    github = github_getting_text(
                "https://github.com/haad/proxychains", 'p[dir=auto]', 1)
    template.template(
                "proxychains",
                "proxychains ",
                github.strip(),
                {
                    "Proxychain github": "https://github.com/haad/proxychains/tree/master",
                    "Proxychain How to use": "https://proxychains.sourceforge.net/howto.html",
                },
            )
def nipe():
    os.system("clear")
    github = github_getting_text(
                "https://github.com/htrgouvea/nipe", 'p[dir=auto]', 4)
    template.template(
                "nipe",
                "nipe",
                github.strip(),
                {
                    "nipe github": "https://github.com/htrgouvea/nipe/blob/main/README.md",
                    "How to Install Nipe tool in Kali Linux?": "https://www.geeksforgeeks.org/how-to-install-nipe-tool-in-kali-linux/",
                }, method="github", github_install="git clone https://github.com/htrgouvea/nipe.git && cd nipe &&  sudo cpan install Try::Tiny Config::Simple JSON && sudo perl nipe.pl install", github_check="nipe")

if __name__ == "__main__":
    main()



from cyberonix.main.tools import banner, colors, template,Vulnerability_Analysis
import os
import requests
from bs4 import BeautifulSoup

# main function


def main():
    while True:
        os.system("clear")
        banner.main()
        banner.attack("Sniffing & Spoofing")
        list_attacks = [" Wireshark\t\t(Recommended)", " Bettercap\t\t(Recommended)", " Tcpdump", " Dsniff", " Scapy", " Netsniff-ng", " Macchanger",
                        " Responder", " Airgeddon",  "Wifi-Pumpkin-3\t(Recommended)", "mitmproxy\t\t(Recommended) ", "zaproxy ", "Go Back"]
        for i in range(len(list_attacks)):
            print(colors.options, f"{i+1}) {list_attacks[i]}".title(), colors.reset)
        try:
            option = input(f"\n {colors.select}Select An Option ->{colors.reset}  ")
        except KeyboardInterrupt:
            return
        if option == "1":
            print("\n[+] Wireshark")
            Vulnerability_Analysis.wireshark()
        elif option == "2":
            print("\n[+] Bettercap")
            bettercap()
        elif option == "3":
            print("\n[+] Tcpdump")
            tcpdump()    
        elif option == "4":
            print("\n[+] Dsniff")
            dsniff()        
        elif option == "5":
            print("\n[+] Scapy")
            scapy()
        elif option == "6":
            print("\n[+] Netsniff-ng")
            netsniff_ng()    
        elif option == "7":
            print("\n[+] Macchanger")
            macchanger()        
        elif option == "8":
            print("\n[+] Responder")
            responder()    
        elif option == "9":
            print("\n[+] Airgeddon")
            airgeddon()               
        elif option == "10":
            print("\n[+] Wifi-Pumpkin-3")
            wifipumpkin3()        
        elif option == "11":
            print("\n[+] mitmproxy")
            mitmproxy()        
        elif option == "12":
            print("\n[+] zaproxy")
            zaproxy()        
        else:
            return


def github_getting_text(link, selector, indexvalue):
    print("Please Wait....\r", end="")
    URL = link
    try:
        r = requests.get(URL)
        soup = BeautifulSoup(r.content, 'html.parser')
        paras = soup.select(selector)
        # check index value from test file
        return paras[indexvalue].text
    except:
        return f"{colors.red}Not Loaded Because No Internet Connection{colors.reset}"

def tcpdump():
    os.system("clear")
    github = github_getting_text(
                "https://opensource.com/article/18/10/introduction-tcpdump", 'p', 5)
    template.template("tcpdump", "tcpdump -h", github.strip()+'\r\n - '.join(github.strip().split('\n')), {"TCPDump": "https://www.qnx.com/developers/docs/7.0.0/index.html#com.qnx.doc.neutrino.utilities/topic/t/tcpdump.html", "Deep Packet Analysis":
                              "https://thwack.solarwinds.com/resources/b/geek-speak/posts/deep-packet-analysis---practical-applications-with-tcpdump", "TCPDump F5": "https://support.f5.com/csp/article/K2289", "TCPDump FreeBSD": "https://www.freebsd.org/cgi/man.cgi?tcpdump"})
       
       
def dsniff():
    os.system("clear")
    github = "dsniff is a collection of tools for network auditing and penetration testing. dsniff, filesnarf, mailsnarf, msgsnarf, urlsnarf, and webspy passively monitor a network for interesting data (passwords, e-mail, files, etc.). arpspoof, dnsspoof, and macof facilitate the interception of network traffic normally unavailable to an attacker (e.g, due to layer-2 switching). sshmitm and webmitm implement active monkey-in-the-middle attacks against redirected SSH and HTTPS sessions by exploiting weak bindings in ad-hoc PKI."
    template.template("dsniff", "dsniff -h", github.strip(), {"Dsniff Repo": "https://github.com/tecknicaltom/dsniff",
                              "Manpages Dsniff": "https://www.unix.com/man-page/debian/8/dsniff/", "Introduction": "http://www.ouah.org/dsniffintr.htm"})
        
def scapy():
    os.system("clear")
    github = "Scapy is a Python program that enables the user to send, sniff and dissect and forge network packets. This capability allows construction of tools that can probe, scan or attack networks."
    template.template("scapy", "chmod +x run_scapy && ./run_scapy", github.strip(), {"what is Scapy": "https://www.freecodecamp.org/news/how-to-use-scapy-python-networking/", "Scapy Introduction": "https://scapy.readthedocs.io/en/latest/introduction.html", "Scapy Usage": "https://python.astrotech.io/network/transport/scapy.html", "Scapy Tutorial": "https://youtu.be/LvaII2PEwcQ",
                              "https://datascientest.com/en/scapy-everything-you-need-to-know-about-the-python-based-network-packaging-tool": "https://datascientest.com/en/scapy-everything-you-need-to-know-about-the-python-based-network-packaging-tool"}, method="github", github_install="git clone https://github.com/secdev/scapy.git", github_check="scapy")
        
def netsniff_ng():
    os.system("clear")
    github_text_0 = github_getting_text(
                "http://netsniff-ng.org/", 'p', 0)
    github_text_1 = github_getting_text(
                "http://netsniff-ng.org/", 'p', 1)
    github_text_2 = github_getting_text(
                "http://netsniff-ng.org/", 'p', 2)
    github = github_text_0.strip().replace("\n", "").replace("\t", "") + github_text_1.strip().replace("\n", "").replace("\t", "") + github_text_2.strip().replace("\n", "").replace("\t", "")
    template.template("netsniff-ng", "netsniff-ng -h", github.strip(), {"Netsniff-ng Website": "http://netsniff-ng.org/", "Sniffing Network Traffic": "https://medium.com/purple-team/sniffing-network-traffic-with-netsniff-ng-55b8f5d436c2",
                              "Manual": "https://linux.die.net/man/8/netsniff-ng", "Video Resources": "https://www.irongeek.com/i.php?page=videos/hack3rcon4/09-netsniff-ng-jon-schipp"})
        
def macchanger():
    os.system("clear")
    github_fetch = github_getting_text(
                "https://www.kali.org/tools/macchanger/", 'p', 0)
    github = github_fetch.strip().replace("\n", "").replace("\t", "")
    template.template("macchanger", "macchanger --help", github.strip(), {"How to Change Mac Address": "https://linuxconfig.org/how-to-change-mac-address-using-macchanger-on-kali-linux/",
                              "Macchanger on Kali Linux": "https://kennyvn.com/change-mac-address-macchanger-kali-linux/", "Permanently Change Mac Address": "https://www.linuxuprising.com/2018/05/how-to-permanently-change-mac-address.html"})
        
def responder():
    os.system("clear")
    github_text_0 = github_getting_text(
                "https://www.kali.org/tools/responder/", 'p', 1)
    github_text_1 = github_getting_text(
                "https://www.kali.org/tools/responder/", 'p', 2)
    github = github_text_0.strip().replace("\n", "").replace("\t", "") + github_text_1.strip().replace("\n", "").replace("\t", "")
    template.template("responder", "responder -h", github, {"Responder-Guide": "https://www.ivoidwarranties.tech/posts/pentesting-tuts/responder/guide/", "How-To-Use-Responder-to-Capture-NETNTLM-and-Grab-a-Shell":
                              "https://www.a2secure.com/blog-en/how-to-use-responder-to-capture-netntlm-and-grab-a-shell/", "infinitelogins.com-Responder": "https://infinitelogins.com/tag/responder/", "Capture-Window-10-NTLM-Hashes-Responder": "https://secnhack.in/capture-window-10-ntlm-hashes-responder"})
        
def airgeddon():
    os.system("clear")
    github = "Airgeddon is a wireless security auditing tool that is used to assess the security of wireless networks. It can be used to perform various types of attacks, such as cracking WPA/WPA2 passwords, capturing WPA/WPA2 handshakes, and identifying vulnerable wireless access points. The tool is open-source and runs on Linux systems. Airgeddon is not intended for illegal use, and should only be used on networks that you have permission to test."
    template.template("airgeddon", "airgeddon", github.strip(), {"How to Use Airgeddon in Kali Linux": "https://www.systranbox.com/how-to-use-airgeddon-in-kali-linux/", "Airgeddon Wifi Crack in Kali Linux": "https://www.kalilinux.in/2021/03/airgeddon-wifi-crack-kalilinux.html",
                              "Airgeddon Multi-Use Bash Script to Audit Wireless Networks": "https://xploitlab.com/airgeddon-multi-use-bash-script-to-audit-wireless-networks/", "Airgeddon Tool Installation and Fix All Errors": "https://www.hacknos.com/airgeddon-tool-installation-and-fix-all-errors/"})
        
def wifipumpkin3():
    os.system("clear")
    github = github_getting_text(
                "https://wifipumpkin3.github.io/", 'p', 1)
    template.template("wifipumpkin3", "wifipumpkin3", github.strip(), {
                              "Wireless Penetration Testing": "https://www.hackingarticles.in/wireless-penetration-testing-wifipumpkin3/", "WiFiPumpkin3 : Powerful Framework For Rogue Access Point Attack": "https://kalilinuxtutorials.com/wifipumpkin3/"})
        
def mitmproxy():
    os.system("clear")
    github = "mitmproxy is an interactive, SSL/TLS-capable intercepting proxy with a console interface for HTTP/1, HTTP/2, and WebSockets.mitmdump is the command-line version of mitmproxy. Think tcpdump for HTTP.mitmweb is a web-based interface for mitmproxy."
    template.template("mitmproxy", "mitmproxy", github.strip(), {
                              "An Introduction to mitmproxy": "https://medium.com/ciandt-techblog/an-introduction-to-mitmproxy-f3654e6bd53b", "mitmproxy docs": "https://docs.mitmproxy.org/stable/", })
        
def zaproxy():
    os.system("clear")
    github = github_getting_text(
                "https://github.com/zaproxy/zaproxy", 'p[dir=auto]', 2)
    template.template("zaproxy", "zaproxy", github.strip(), {
                              "Overview ZAP": "https://www.zaproxy.org/getting-started/", })
        
def bettercap():
    os.system("clear")
    github = github_getting_text(
                "https://www.bettercap.org/intro/", 'p', 0)
    template.template("bettercap", "bettercap", github.strip(), {"Man in the Middle": "https://www.cybervie.com/blog/easy-and-better-man-in-the-middle-using-bettercap/", "MITM Labs Write-up":
                              "https://charlesreid1.com/wiki/MITM_Labs/Bettercap_Over_Wifi", "NTLM Capturing": "https://blog.xpnsec.com/bettercap-capturing-ntlm/", "DNS Spoofing": "https://psychovik.medium.com/dns-spoofing-using-bettercap-24a8435f7a03"})
        

if __name__ == '__main__':
    main()
